//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Data/DataItemUtil.cpp
//! @brief     Implements class DataItemUtils
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Data/DataItemUtil.h"
#include "Base/Axis/Frame.h"
#include "Base/Axis/Scale.h"
#include "Base/Util/Assert.h"
#include "Device/Data/Datafield.h"
#include "GUI/Model/Data/DataItem.h"

void GUI::Model::DataItemUtil::updateAxesTitle(DataItem* intensityItem, const Frame& frame)
{
    intensityItem->setXaxisTitle(QString::fromStdString(frame.axis(0).axisName()));
    if (frame.rank() > 1)
        intensityItem->setYaxisTitle(QString::fromStdString(frame.axis(1).axisName()));
}

//! Updates axes of Datafield in IntensityData item to correspond with axes units selection.
//! InstrumentItem is used to get domain's detector map for given units.

void GUI::Model::DataItemUtil::updateDataAxes(DataItem* dataItem, const Frame& frame)
{
    ASSERT(dataItem);
    const Datafield* oldData = dataItem->c_field();
    if (!oldData)
        return;

    auto newData = std::make_unique<Datafield>(frame.clonedAxes(), oldData->flatVector(),
                                               oldData->errorSigmas());

    dataItem->setDatafield(newData.release());
    dataItem->setAxesRangeToData();
    updateAxesTitle(dataItem, frame);
}

void GUI::Model::DataItemUtil::createDefaultDetectorMap(DataItem* dataItem, const Frame& frame)
{
    auto output_data = std::make_unique<Datafield>(frame.clonedAxes());
    dataItem->setDatafield(output_data.release());
    updateAxesTitle(dataItem, frame);
}

void GUI::Model::DataItemUtil::setResults(DataItem* dataItem, const Datafield& result)
{
    if (dataItem->c_field() == nullptr) {
        const auto& frame = result.frame();
        updateAxesTitle(dataItem, frame);
    }
    dataItem->setDatafield(new Datafield(result.frame().clonedAxes(), result.flatVector()));
}
